@@ -20,13 +20,10 @@
 
 #include "nodewrapper.h"
 #include "edgewrapper.h"
-#include "graphdocument.h"
 #include "nodetype.h"
 #include "edge.h"
-#include "typenames.h"
 #include <KLocalizedString>
 #include <QPointF>
-#include <QColor>
 #include <QDebug>
 #include <QEvent>
 
